@@ -21,7 +21,7 @@ Base configuration data
 """
 __version__ = "$Revision: 61095 $"
 # $Source$
-# $Id: config.py 241647 2011-06-29 16:54:05Z yboussard $
+# $Id: config.py 241683 2011-06-30 07:51:47Z yboussard $
 __docformat__ = 'restructuredtext'
 
 # CMF imports
@@ -85,5 +85,5 @@ else:
 from Log import *
 Log = Log
 Log(LOG_NOTICE, "Starting %s at %d debug level" % (os.path.dirname(__file__), LOG_LEVEL, ))
-TRACE_SEND_MAIL = getConfiguration().product_config.get('plonesubscription',{}).get('debug_send_mail', False)
+TRACE_SEND_MAIL = getConfiguration().product_config.get('plonesubscription',{}).get('trace_send_mail', False)
 Log(LOG_NOTICE, "Trace send mail %s" %  (TRACE_SEND_MAIL and 'ON' or 'OFF'))
